@@ -178,8 +178,11 @@ yaml_parser_parse(yaml_parser_t *parser, yaml_event_t *event)
 
     /* No events after the end of the stream or error. */
 
-    if (parser->stream_end_produced || parser->error ||
-            parser->state == YAML_PARSE_END_STATE) {
+    if (parser->stream_end_produced ||
+        (parser->error &&
+           /* continue in nonstrict and READER_ERROR */
+           (!parser->problem_nonstrict || parser->error != YAML_READER_ERROR)) ||
+         parser->state == YAML_PARSE_END_STATE) {
         return 1;
     }
 
@@ -390,7 +393,8 @@ yaml_parser_parse_document_start(yaml_parser_t *parser, yaml_event_t *event,
                     &tag_directives.start, &tag_directives.end))
             return 0;
         token = PEEK_TOKEN(parser);
-        if (!token) goto error;
+        if (!token)
+            goto error;
         if (token->type != YAML_DOCUMENT_START_TOKEN) {
             yaml_parser_set_parser_error(parser,
                     "did not find expected <document start>", token->start_mark);
@@ -484,7 +488,7 @@ yaml_parser_parse_document_end(yaml_parser_t *parser, yaml_event_t *event)
         implicit = 0;
     }
 
-    while (!STACK_EMPTY(parser, parser->tag_directives)) {
+    while (!(STACK_EMPTY(parser, parser->tag_directives))) {
         yaml_tag_directive_t tag_directive = POP(parser, parser->tag_directives);
         yaml_free(tag_directive.handle);
         yaml_free(tag_directive.prefix);
@@ -560,7 +564,8 @@ yaml_parser_parse_node(yaml_parser_t *parser, yaml_event_t *event,
             end_mark = token->end_mark;
             SKIP_TOKEN(parser);
             token = PEEK_TOKEN(parser);
-            if (!token) goto error;
+            if (!token)
+                goto error;
             if (token->type == YAML_TAG_TOKEN)
             {
                 tag_handle = token->data.tag.handle;
@@ -569,7 +574,8 @@ yaml_parser_parse_node(yaml_parser_t *parser, yaml_event_t *event,
                 end_mark = token->end_mark;
                 SKIP_TOKEN(parser);
                 token = PEEK_TOKEN(parser);
-                if (!token) goto error;
+                if (!token)
+                    goto error;
             }
         }
         else if (token->type == YAML_TAG_TOKEN)
@@ -580,14 +586,16 @@ yaml_parser_parse_node(yaml_parser_t *parser, yaml_event_t *event,
             end_mark = token->end_mark;
             SKIP_TOKEN(parser);
             token = PEEK_TOKEN(parser);
-            if (!token) goto error;
+            if (!token)
+                goto error;
             if (token->type == YAML_ANCHOR_TOKEN)
             {
                 anchor = token->data.anchor.value;
                 end_mark = token->end_mark;
                 SKIP_TOKEN(parser);
                 token = PEEK_TOKEN(parser);
-                if (!token) goto error;
+                if (!token)
+                    goto error;
             }
         }
 
@@ -1249,7 +1257,8 @@ yaml_parser_process_directives(yaml_parser_t *parser,
         goto error;
 
     token = PEEK_TOKEN(parser);
-    if (!token) goto error;
+    if (!token)
+        goto error;
 
     while (token->type == YAML_VERSION_DIRECTIVE_TOKEN ||
             token->type == YAML_TAG_DIRECTIVE_TOKEN)
@@ -1289,9 +1298,10 @@ yaml_parser_process_directives(yaml_parser_t *parser,
 
         SKIP_TOKEN(parser);
         token = PEEK_TOKEN(parser);
-        if (!token) goto error;
+        if (!token)
+            goto error;
     }
-
+    
     for (default_tag_directive = default_tag_directives;
             default_tag_directive->handle; default_tag_directive++) {
         if (!yaml_parser_append_tag_directive(parser, *default_tag_directive, 1,
@@ -1320,7 +1330,7 @@ yaml_parser_process_directives(yaml_parser_t *parser,
 
 error:
     yaml_free(version_directive);
-    while (!STACK_EMPTY(parser, tag_directives)) {
+    while (!(STACK_EMPTY(parser, tag_directives))) {
         yaml_tag_directive_t tag_directive = POP(parser, tag_directives);
         yaml_free(tag_directive.handle);
         yaml_free(tag_directive.prefix);
