@@ -11,20 +11,20 @@
         PerlInterpreter *orig_perl = PERL_GET_CONTEXT; \
         SAVESPTR(orig_perl); \
         PERL_SET_CONTEXT(aTHX); \
-        qsort((char *) AvARRAY(av), len, sizeof(SV *), sortcmp); \
+        qsort((char *) AvARRAY(av), AvFILLp(av), sizeof(SV *), sortcmp); \
         } LEAVE;
 
 #else /* ! USE_ITHREADS */
 
 #define STORE_HASH_SORT \
-        qsort((char *) AvARRAY(av), len, sizeof(SV *), sortcmp);
+        qsort((char *) AvARRAY(av), AvFILLp(av), sizeof(SV *), sortcmp);
 
 #endif  /* USE_ITHREADS */
 
 #else /* PATCHLEVEL > 6 */
 
 #define STORE_HASH_SORT \
-        sortsv(AvARRAY(av), len, Perl_sv_cmp);  
+        sortsv(AvARRAY(av), len, Perl_sv_cmp);
 
 #endif /* PATCHLEVEL <= 6 */
 
