@@ -1,3 +1,4 @@
+
 #if HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -8,6 +9,16 @@
 #include <limits.h>
 #include <stddef.h>
 
+#ifndef _MSC_VER
+#include <stdint.h>
+#else
+#ifdef _WIN64
+#define PTRDIFF_MAX _I64_MAX
+#else
+#define PTRDIFF_MAX INT_MAX
+#endif
+#endif
+
 /*
  * Memory management.
  */
@@ -66,17 +77,6 @@ yaml_parser_fetch_more_tokens(yaml_parser_t *parser);
 
 #define OUTPUT_RAW_BUFFER_SIZE  (OUTPUT_BUFFER_SIZE*2+2)
 
-/*
- * The maximum size of a YAML input file.
- * This used to be PTRDIFF_MAX, but that's not entirely portable
- * because stdint.h isn't available on all platforms.
- * It is not entirely clear why this isn't the maximum value
- * that can fit into the parser->offset field.
- */
-
-#define MAX_FILE_SIZE (~(size_t)0 / 2)
-
-
 /*
  * The size of other stacks and queues.
  */
@@ -171,8 +171,8 @@ yaml_string_join(
  * Check the octet at the specified position.
  */
 
-#define CHECK_AT(string,octet,offset)                                           \
-    ((string).pointer[offset] == (yaml_char_t)(octet))
+#define CHECK_AT(string,octet,offset)                   \
+    (string).pointer[offset] == (yaml_char_t)(octet)
 
 /*
  * Check the current octet in the buffer.
@@ -242,9 +242,9 @@ yaml_string_join(
         (string).pointer[offset] <= (yaml_char_t) 'f') ?                        \
        ((string).pointer[offset] - (yaml_char_t) 'a' + 10) :                    \
        ((string).pointer[offset] - (yaml_char_t) '0'))
-
+ 
 #define AS_HEX(string)  AS_HEX_AT((string),0)
-
+ 
 /*
  * Check if the character is ASCII.
  */
@@ -433,7 +433,7 @@ yaml_queue_extend(void **start, void **head, void **tail, void **end);
      (stack).start = (stack).top = (stack).end = 0)
 
 #define STACK_EMPTY(context,stack)                                              \
-    ((stack).start == (stack).top)
+    (stack).start == (stack).top
 
 #define STACK_LIMIT(context,stack,size)                                         \
     ((stack).top - (stack).start < (size) ?                                     \
@@ -466,7 +466,7 @@ yaml_queue_extend(void **start, void **head, void **tail, void **end);
      (queue).start = (queue).head = (queue).tail = (queue).end = 0)
 
 #define QUEUE_EMPTY(context,queue)                                              \
-    ((queue).head == (queue).tail)
+    (queue).head == (queue).tail
 
 #define ENQUEUE(context,queue,value)                                            \
     (((queue).tail != (queue).end                                               \
